@@ -1,8 +1,8 @@
 """
 Tutorial - Sessions
 
-Storing session data in CherryPy applications is very easy: cherrypy.request
-provides a dictionary called sessionMap that represents the session
+Storing session data in CherryPy applications is very easy: cherrypy
+provides a dictionary called "session" that represents the session
 data for the current user. If you use RAM based sessions, you can store
 any kind of object into that dictionary; otherwise, you are limited to
 objects that can be pickled.
@@ -12,6 +12,9 @@ import cherrypy
 
 
 class HitCounter:
+    
+    _cp_config = {'tools.sessions.on': True}
+    
     def index(self):
         # Increase the silly hit counter
         count = cherrypy.session.get('count', 0) + 1
@@ -27,10 +30,12 @@ class HitCounter:
     index.exposed = True
 
 
-cherrypy.root = HitCounter()
-cherrypy.config.update({'sessionFilter.on': True})
+cherrypy.tree.mount(HitCounter())
+
 
 if __name__ == '__main__':
-    cherrypy.config.update(file = 'tutorial.conf')
-    cherrypy.server.start()
+    import os.path
+    cherrypy.config.update(os.path.join(os.path.dirname(__file__), 'tutorial.conf'))
+    cherrypy.server.quickstart()
+    cherrypy.engine.start()
 
